package com.kingdee.eas.custom.dormitorysystem.application.handler;

import com.kingdee.bos.BOSException;
import com.kingdee.bos.Context;
import com.kingdee.eas.common.EASBizException;
import com.kingdee.eas.framework.CoreBaseInfo;
import com.kingdee.eas.hr.base.HRBillBaseInfo;
import com.kingdee.shr.base.syssetting.IMSFServiceFacade;
import com.kingdee.shr.base.syssetting.MSFServiceFacadeFactory;
import com.kingdee.shr.base.syssetting.context.SHRContext;
import com.kingdee.shr.base.syssetting.exception.SHRWebException;
import com.kingdee.shr.base.syssetting.exception.ShrWebBizException;
import com.kingdee.shr.base.syssetting.web.handler.ListHandler;
import org.apache.log4j.Logger;
import org.springframework.ui.ModelMap;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description 뵥ͨHandler
 * @Date 2025/4/29 9:32
 * @Created by Heyuan
 */
public class DormitoryApplicationListHandler extends ListHandler {
    private static Logger logger = Logger.getLogger(DormitoryApplicationListHandler.class);
    private Context ctx = SHRContext.getInstance().getContext();

    @Override
    protected void beforeSubmit(
            HttpServletRequest request,
            HttpServletResponse response,
            CoreBaseInfo model
    ) throws SHRWebException {
        HRBillBaseInfo hrBillBaseInfo = (HRBillBaseInfo) model;
        String billIds = hrBillBaseInfo.getId().toString();
        Map result = null;
        Map<String, String> params = new HashMap<String, String>();
        params.put("billIds", billIds);
        try {
            IMSFServiceFacade imsfServiceFacade = MSFServiceFacadeFactory.getLocalInstance(ctx);
            result = (Map) imsfServiceFacade.processService("validateRoomAvailableByBillIdsService", params);
        } catch (Exception e) {
            logger.error(e);
            throw new ShrWebBizException("ýӿvalidateRoomAvailableByBillIdsService: " + e.getMessage());
        }
        Integer code = (Integer) result.get("code");
        if (500 == code) {
            List<String> errorMsgList = (List<String>) result.get("errorMsg");
            StringBuilder errorMsgBuilder = new StringBuilder();
            for (String errorMsg : errorMsgList) {
                errorMsgBuilder.append(errorMsg).append("\n");
            }
            throw new ShrWebBizException(errorMsgBuilder.toString());
        }
        super.beforeSubmit(request, response, model);
    }

    /**
     * ύЧ
     *
     * @param request
     * @param response
     * @param modelMap
     * @throws SHRWebException
     * @throws BOSException
     */
    public void submitEffectAction(
            HttpServletRequest request,
            HttpServletResponse response,
            ModelMap modelMap
    ) throws SHRWebException, BOSException {
        this.handleEnableWithTips(request, "submitEffect");
    }


    /**
     * 
     *
     * @param request
     * @param response
     * @param modelMap
     * @throws SHRWebException
     * @throws BOSException
     */
    public void againstApproveAction(
            HttpServletRequest request,
            HttpServletResponse response,
            ModelMap modelMap
    ) throws SHRWebException, BOSException {
        this.handleEnableWithTips(request, "untiCheckBizBill");
    }

    /**
     * 
     *
     * @param request
     * @param response
     * @param modelMap
     * @throws SHRWebException
     * @throws EASBizException
     * @throws BOSException
     */
    public void abortBizBillAction(
            HttpServletRequest request,
            HttpServletResponse response,
            ModelMap modelMap
    ) throws SHRWebException {
        this.handleEnableWithTips(request, "abortBizBill");
    }
}
